/* test program for m2-identconv, by B.Kowarsch 2016 */

#include "m2-identconv.h"

#include <stdio.h>
#include <stdlib.h>


void print_usage(void) {
  printf("test program for identifier conversion\n");
  printf("usage: idconvtest qualifier identifier [mode]\n");
  printf("  where mode is -c for C style conversion.\n");
} /* end print_usage */


int main (int argc, char *argv[]) {
  const char *qualifier, *ident, *mode;
  char *cid, buffer[M2C_MAX_C_MACRO_LENGTH+1];
  
  if ((argc < 3) || (argc > 4)) {
    print_usage();
    exit(EXIT_FAILURE);
  } /* end if */
  
  qualifier = argv[1];
  ident = argv[2];
    
  if (argc == 4) {
    mode = argv[3];
    if ((mode[0] == '-') && (mode[1] == 'c') && (mode[2] == 0)) {
      set_cstyle_option();
    }
    else {
      print_usage();
      exit(EXIT_FAILURE);
    } /* end if */
  } /* end if */
  
  cid = (char *) &buffer;
  
  get_include_guard_ident(&cid, qualifier); 
  printf("C include guard:\n  %s\n\n", cid);
  
  get_public_const_ident(&cid, qualifier, ident); 
  printf("Public constant:\n  %s\n\n", cid);
  
  get_public_type_ident(&cid, qualifier, ident); 
  printf("Public type:\n  %s\n\n", cid);
  
  get_public_vfn_ident(&cid, qualifier, ident); 
  printf("Public variable or function:\n  %s\n\n", cid);
  
  get_private_const_ident(&cid, ident); 
  printf("Private constant:\n  %s\n\n", cid);
  
  get_private_type_ident(&cid, ident); 
  printf("Private type:\n  %s\n\n", cid);
  
  get_private_vfn_ident(&cid, ident); 
  printf("Private variable or function:\n  %s\n\n", cid);
  
  get_local_const_ident(&cid, qualifier, 0, ident); 
  printf("Local constant:\n  %s\n\n", cid);
  
  get_local_type_ident(&cid, qualifier, 0, ident); 
  printf("Local type:\n  %s\n\n", cid);
  
  get_local_var_ident(&cid, ident); 
  printf("Local variable:\n  %s\n\n", cid);
  
  get_local_fn_ident(&cid, qualifier, 0, ident); 
  printf("Local function:\n  %s\n\n", cid);
    
  return 0;
} /* end main */

/* END OF FILE */